set terminal pdfcairo enhanced color size 4,4 fontscale 0.5\
    font 'Arial,14' linewidth 1 dl 2
    
set key font ',12'

set ylabel offset 1
set xlabel offset 0,0.5

set lmargin 9
set rmargin 9
set tmargin 3
set bmargin 6

set style line 1 dashtype 1 lw 2 ps 0.75 pt 2 lc rgb '#1B9E77' # dark teal
set style line 2 dashtype 1 lw 2 ps 0.75 pt 4 lc rgb '#D95F02' # dark orange
set style line 3 dashtype 1 lw 2 ps 0.75 pt 6 lc rgb '#7570B3' # dark lilac
set style line 4 dashtype 1 lw 2 ps 0.75 pt 8 lc rgb '#E7298A' # dark magenta
set style line 5 dashtype 1 lw 2 ps 0.75 pt 10 lc rgb '#66A61E' # dark lime green
set style line 6 dashtype 1 lw 2 ps 0.75 pt 2 lc rgb '#E6AB02' # dark banana
set style line 7 dashtype 1 lw 2 ps 0.75 pt 3 lc rgb '#A6761D' # dark tan
set style line 8 dashtype 1 lw 2 ps 0.75 pt 5 lc rgb '#666666' # dark gray
set style line 9 dashtype 1 lw 2 ps 0.75 pt 7 lc rgb "#cab2d6"
set style line 10 dashtype 1 lw 2 ps 0.75 pt 9 lc rgb "#6a3d9a"
set style line 11 dashtype 1 lw 2 ps 0.75 pt 11 lc rgb "#222222"
set style line 12 dashtype 1 lw 2 ps 0.75 pt 13 lc rgb "#b15928"

set output "PAPER r9p3 plot.pdf"

set samples 100000
set xrange [1:2.7]
set yrange [0:105]

set xlabel "Deformation, {/Symbol l}_x"
set ylabel "Director angle [{\260}]"
l_crit = 9.3**(1.0/3.0)

##ANGLE FUNCTION
#l is lambda_critical according the W&T for MFT transition
#t is theta_0 - the intial director angle
#f(x) gives the current director angle based on the initial angle, lambda_crit and the deformation
f(x,l,t) = 90/pi*atan((2*(l**3-1)*sin(2*t)*x**(1.5))/((l**3+1)*(x**3-1)+(l**3-1)*(x**3+1)*cos(2*t)))

###CROSSOVER LAMBDA FOR DEGENERATE ANGLES (ONLY REQUIRED FOR INITIAL ANGLE>45)

top(x,l_c,a_0) = ((l_c**3-1)*(1-cos(pi*a_0/90))+2)
bottom(x,l_c,a_0) = ((l_c**3-1)*(1+cos(pi*a_0/90))+2)
cross(x, l_c, a_0) = (top(x,l_c,a_0)/bottom(x,l_c,a_0))**(1.0/3.0)


g(x,l_1,a_1,y_shift1) = (x > 0 && x < cross(x, l_1, a_1)) ? f(x, l_1, a_1*pi/180)+y_shift1 : 1/0
h(x,l_2,a_2,y_shift2) = (x > cross(x, l_2, a_2) && x < 3) ? f(x, l_2, a_2*pi/180)+y_shift2 : 1/0

a_89 = 89
a_70 = 70
a_54 = 54
a_39 = 39
a_28 = 28

plot "70.txt" u($1+1):3 ls 2 notitle,\
    "54.txt" u($1+1):3 ls 3 notitle,\
    "39.txt" u($1+1):3 ls 4 notitle,\
    "28.txt" u($1+1):3 ls 5 notitle,\
    "19.txt" u($1+1):3 ls 6 notitle,\
    "15.txt" u($1+1):3 ls 7 notitle,\
    "12.txt" u($1+1):3 ls 8 notitle,\
    "08.txt" u($1+1):3 ls 9 notitle,\
    "05.txt" u($1+1):3 ls 10 notitle,\
    "03.txt" u($1+1):3 ls 11 notitle,\
    "02.txt" u($1+1):3 ls 12 notitle,\
    "89.txt" u($1+1):3 ls 1 notitle,\
    g(x,l_crit,a_89,90) ls 1 dashtype 2 notitle, h(x,l_crit,a_89,0) ls 1 dashtype 2 title "{/Symbol q}_0 = 89{\260}",\
    g(x,l_crit,88,90) ls 1  dashtype 1 notitle, h(x,l_crit,88,0) ls 1 dashtype 1 title "88{\260}",\
    g(x,l_crit,a_70,90) ls 2 notitle, h(x,l_crit,a_70,0) ls 2 title "70{\260}",\
    g(x,l_crit,a_54,90) ls 3 notitle, h(x,l_crit,a_54,0) ls 3 title "54{\260}",\
    g(x,l_crit,a_39,0) ls 4 notitle, h(x,l_crit,a_39,0) ls 4 title "39{\260}",\
    g(x,l_crit,a_28,0) ls 5 notitle, h(x,l_crit,a_28,0) ls 5 title "28{\260}",\
    g(x,l_crit,19,0) ls 6 notitle, h(x,l_crit,19,0) ls 6 title "19{\260}",\
    g(x,l_crit,15,0) ls 7 notitle, h(x,l_crit,15,0) ls 7 title "15{\260}",\
    g(x,l_crit,12,0) ls 8 notitle, h(x,l_crit,12,0) ls 8 title "12{\260}",\
    g(x,l_crit,8,0) ls 9 notitle, h(x,l_crit,8,0) ls 9 title "8{\260}",\
    g(x,l_crit,5,0) ls 10 notitle, h(x,l_crit,5,0) ls 10 title "5{\260}",\
    g(x,l_crit,3,0) ls 11 notitle, h(x,l_crit,3,0) ls 11 title "3{\260}",\
    g(x,l_crit,2,0) ls 12 notitle, h(x,l_crit,2,0) ls 12 title "2{\260}",\



#pause -1